@@ -53,13 +53,17 @@ struct _WnckWorkspaceClass
 
 GType wnck_workspace_get_type (void) G_GNUC_CONST;
 
-int wnck_workspace_get_number (WnckWorkspace *space);
+int         wnck_workspace_get_number     (WnckWorkspace *space);
+const char* wnck_workspace_get_name       (WnckWorkspace *space);
+void        wnck_workspace_change_name    (WnckWorkspace *space,
+                                           const char    *name);
+void        wnck_workspace_activate       (WnckWorkspace *space);
+int         wnck_workspace_get_width      (WnckWorkspace *space);
+int         wnck_workspace_get_height     (WnckWorkspace *space);
+int         wnck_workspace_get_viewport_x (WnckWorkspace *space);
+int         wnck_workspace_get_viewport_y (WnckWorkspace *space);
+gboolean    wnck_workspace_is_virtual     (WnckWorkspace *space);
 
-const char* wnck_workspace_get_name    (WnckWorkspace *space);
-void        wnck_workspace_change_name (WnckWorkspace *space,
-                                        const char    *name);
-
-void wnck_workspace_activate (WnckWorkspace *space);
 
 G_END_DECLS
 
